@@ -50,7 +50,7 @@ get_data_list <- function(analysis_type, family, link, models, Mlist,
                       dimnames = list(subj = c(), time = c()))
     for (j in 1:(length(etimes) - 1)) {
       Y[, j] <- ifelse(y - etimes[j] + defs$coxph['eps'] > 0, 1, 0)
-      dN[, j] <- Y[, j] * ifelse(etimes[j + 1] - y - defs$coxph['eps'] > 0, 1, 0) * (as.numeric(unlist(Mlist$cens)) - 1)
+      dN[, j] <- Y[, j] * ifelse(etimes[j + 1] - y - defs$coxph['eps'] > 0, 1, 0) * unlist(Mlist$cens)
     }
 
     priorhaz <- numeric(length(etimes) - 1)
@@ -83,7 +83,7 @@ get_data_list <- function(analysis_type, family, link, models, Mlist,
          scaled$scaled_matrices[!sapply(scaled$scaled_matrices, is.null)]
   )
 
-  if (is.null(models) & family == 'ordinal')
+  if (is.null(models) & all(sapply(Mlist$cols_main, is.null)))
     l$Xc <- NULL
 
   if (!is.null(Mlist$Xcat)) l$Xcat <- data.matrix(Mlist$Xcat)
@@ -91,11 +91,15 @@ get_data_list <- function(analysis_type, family, link, models, Mlist,
   if (!is.null(Mlist$Xic)) l$Xic <- data.matrix(Mlist$Xic)
   if (!is.null(Mlist$Xil)) l$Xil <- data.matrix(Mlist$Xil)
 
+  if (all(is.null(Mlist$cols_main$Xl),
+          is.null(unlist(sapply(imp_par_list, '[[', 'Xl_cols'))))) {
+    l$Xl <- NULL
+  }
 
   if (any(models %in% c('norm', 'lognorm', 'lme', 'lmm')) | (family == 'gaussian' & !Mlist$ridge))
     l <- c(l, defs$norm)
   else if (family == 'gaussian' & Mlist$ridge)
-    l <- c(l, defs$norm["mu_reg_norm", "shape_tau_norm", "rate_tau_norm"])
+    l <- c(l, defs$norm[c("mu_reg_norm", "shape_tau_norm", "rate_tau_norm")])
 
 
   if ((family == 'binomial' & link == 'logit' & !Mlist$ridge) | any(models %in% c('logit', 'glmm_logit')))
@@ -113,7 +117,7 @@ get_data_list <- function(analysis_type, family, link, models, Mlist,
   if ((family == 'Gamma' & !Mlist$ridge) | any(models %in% c('gamma', 'glmm_gamma')))
     l <- c(l, defs$gamma)
   else if (family == 'Gamma' & Mlist$ridge)
-    l <- c(l, defs$gamma["mu_reg_gamma", "shape_tau_gamma", "rate_tau_gamma"])
+    l <- c(l, defs$gamma[c("mu_reg_gamma", "shape_tau_gamma", "rate_tau_gamma")])
 
 
   if ((family == 'poisson' & !Mlist$ridge) | any(models %in% c('glmm_poisson')))
@@ -125,8 +129,8 @@ get_data_list <- function(analysis_type, family, link, models, Mlist,
   if (family == 'ordinal' & !Mlist$ridge | any(models %in% c('clmm', "cumlogit")))
     l <- c(l, defs$ordinal)
   else if (family == 'ordinal' & Mlist$ridge)
-    l <- c(l, defs$ordinal["mu_reg_ordinal", "mu_delta_ordinal", "tau_delta_ordinal"])
-  if (family == 'ordinal' & is.null(models))
+    l <- c(l, defs$ordinal[c("mu_reg_ordinal", "mu_delta_ordinal", "tau_delta_ordinal")])
+  if (family == 'ordinal' & is.null(models) & all(sapply(Mlist$cols_main, is.null)))
     l$mu_reg_ordinal <- l$tau_reg_ordinal <- NULL
 
 
