@@ -20,21 +20,21 @@ colnames(tab) <- c('family', ' ')
 
 knitr::kable(tab, row.names = FALSE)
 
-## -------------------------------------------------------------------------------------------------
+## ---- message = FALSE-----------------------------------------------------------------------------
 mod1a <- glm_imp(educ ~ age + gender + creat, data = NHANES,
-               family = "binomial", n.adapt = 0, mess = FALSE)
+               family = "binomial", n.adapt = 0)
 
 mod1b <- glm_imp(educ ~ age + gender + creat, data = NHANES,
-               family = binomial(), n.adapt = 0, mess = FALSE)
+               family = binomial(), n.adapt = 0)
 
 mod1c <- glm_imp(educ ~ age + gender + creat, data = NHANES,
-               family = binomial(link = 'logit'), n.adapt = 0, mess = FALSE)
+               family = binomial(link = 'logit'), n.adapt = 0)
 
 mod1a$analysis_type
 
-## -------------------------------------------------------------------------------------------------
+## ---- message = FALSE-----------------------------------------------------------------------------
 mod1d <- glm_imp(educ ~ age + gender + creat, data = NHANES,
-               family = binomial(link = 'probit'), n.adapt = 0, mess = FALSE)
+               family = binomial(link = 'probit'), n.adapt = 0)
 
 mod1d$analysis_type
 
@@ -44,81 +44,83 @@ mod1d$analysis_type
 ## ---- eval = FALSE--------------------------------------------------------------------------------
 #  SBP ~ age + gender + smoke + creat + smoke:creat
 
-## -------------------------------------------------------------------------------------------------
+## ---- message = FALSE-----------------------------------------------------------------------------
 mod2a <- glm_imp(educ ~ gender * (age + smoke + creat),
-                 data = NHANES, family = binomial(), mess = FALSE, n.adapt = 0)
+                 data = NHANES, family = binomial(), n.adapt = 0)
 
-parameters(mod2a, mess = FALSE)
+parameters(mod2a)
 
-## ----multi-way interactions-----------------------------------------------------------------------
+## ----multi-way interactions, message = FALSE------------------------------------------------------
 # all two-way interactions:
 mod2b <- glm_imp(educ ~ gender + (age + smoke + creat)^2,
-                 data = NHANES, family = binomial(), mess = FALSE, n.adapt = 0)
+                 data = NHANES, family = binomial(), n.adapt = 0)
 
-parameters(mod2b, mess = FALSE)
+parameters(mod2b)
 
 # all two- and three-way interactions:
 mod2c <- glm_imp(educ ~ gender + (age + smoke + creat)^3,
-                 data = NHANES, family = binomial(), mess = FALSE, n.adapt = 0)
+                 data = NHANES, family = binomial(), n.adapt = 0)
 
-parameters(mod2c, mess = FALSE)
+parameters(mod2c)
 
-## -------------------------------------------------------------------------------------------------
+## ---- message = FALSE-----------------------------------------------------------------------------
 # Absolute difference between bili and creat
-mod3a <- lm_imp(SBP ~ age + gender + abs(bili - creat),
-                data = NHANES, mess = FALSE)
+mod3a <- lm_imp(SBP ~ age + gender + abs(bili - creat), data = NHANES)
 
 # Using a natural cubic spline for age (completely observed) and a quadratic
 # and a cubic effect for bili
 library(splines)
-mod3b <- lm_imp(SBP ~ ns(age, df = 2) + gender + I(bili^2) + I(bili^3),
-                data = NHANES, mess = FALSE, keep_model = TRUE)
+mod3b <- lm_imp(SBP ~ ns(age, df = 2) + gender + I(bili^2) + I(bili^3), data = NHANES)
 
 # A function of creat and albu
-mod3c <- lm_imp(SBP ~ age + gender + I(creat/albu^2),
-                data = NHANES, mess = FALSE)
+mod3c <- lm_imp(SBP ~ age + gender + I(creat/albu^2), data = NHANES,
+                models = c(creat = 'lognorm', albu = 'lognorm'))
 # This function may make more sense to calculate BMI as weight/height^2, but
-# we do not have those variables in the NHANES data...
+# we currently do not have those variables in the NHANES dataset.
 
 # Using the sinus and cosinus
-mod3d <- lm_imp(SBP ~ bili + sin(creat) + cos(albu),
-                data = NHANES, mess = FALSE)
+mod3d <- lm_imp(SBP ~ bili + sin(creat) + cos(albu), data = NHANES)
 
 ## -------------------------------------------------------------------------------------------------
-list_impmodels(mod3b, priors = FALSE, regcoef = FALSE, otherpars = FALSE)
+list_models(mod3b, priors = FALSE, regcoef = FALSE, otherpars = FALSE)
 
-## -------------------------------------------------------------------------------------------------
-mod3e <- lm_imp(SBP ~ age + gender + bili, auxvars = "I(WC^2)",
-                data = NHANES, mess = FALSE)
+## ---- message = FALSE-----------------------------------------------------------------------------
+mod3e <- lm_imp(SBP ~ age + gender + bili, auxvars = "I(WC^2)", data = NHANES)
 
 list_impmodels(mod3e, priors = F, regcoef = F, otherpars = F)
 
-## -------------------------------------------------------------------------------------------------
+## ---- message = FALSE-----------------------------------------------------------------------------
+mod3f <- lm_imp(SBP ~ age + gender + bili + WC, auxvars = "I(WC^2)", data = NHANES)
+
+list_impmodels(mod3f, priors = F, regcoef = F, otherpars = F)
+
+## ---- message = FALSE-----------------------------------------------------------------------------
+mod3g <- lm_imp(SBP ~ age + gender + bili + I(WC^2), auxvars = "I(WC^2)", data = NHANES)
+
+list_impmodels(mod3g, priors = F, regcoef = F, otherpars = F)
+
+## ---- message = FALSE-----------------------------------------------------------------------------
 # truncation of the distribution of  bili
 mod4a <- lm_imp(SBP ~ age + gender + log(bili) + exp(creat),
-                trunc = list(bili = c(1e-5, 1e10)),
-                data = NHANES, mess = FALSE, keep_model = T)
+                trunc = list(bili = c(1e-5, 1e10)), data = NHANES)
 
 # log-normal model for bili
 mod4b <- lm_imp(SBP ~ age + gender + log(bili) + exp(creat),
-                meth = c(bili = 'lognorm', creat = 'norm'),
-                data = NHANES, mess = FALSE, keep_model = T)
+                models = c(bili = 'lognorm', creat = 'norm'), data = NHANES)
 
 # gamma model for bili
 mod4c <- lm_imp(SBP ~ age + gender + log(bili) + exp(creat),
-                meth = c(bili = 'gamma', creat = 'norm'),
-                data = NHANES, mess = FALSE, keep_model = T)
+                models = c(bili = 'gamma', creat = 'norm'), data = NHANES)
 
 
-## -------------------------------------------------------------------------------------------------
+## ---- message = FALSE-----------------------------------------------------------------------------
 # Define the function ilogit
 ilogit <- plogis
 
 # Use ilogit in the model formula
-mod5a = lm_imp(SBP ~ age + gender + ilogit(creat),
-               data = NHANES, mess = FALSE)
+mod5a = lm_imp(SBP ~ age + gender + ilogit(creat), data = NHANES)
 
-## -------------------------------------------------------------------------------------------------
+## ---- message = FALSE-----------------------------------------------------------------------------
 # define the complementary log log transformation
 cloglog <- function(x) log(-log(1 - x))
 
@@ -126,13 +128,11 @@ cloglog <- function(x) log(-log(1 - x))
 ilogit <- plogis
 
 # nest ilogit inside cloglog
-mod6a = lm_imp(SBP ~ age + gender + cloglog(ilogit(creat)),
-               data = NHANES, mess = FALSE)
+mod6a = lm_imp(SBP ~ age + gender + cloglog(ilogit(creat)), data = NHANES)
 
-## -------------------------------------------------------------------------------------------------
+## ---- message = FALSE-----------------------------------------------------------------------------
 mod7a <- lme_imp(bmi ~ GESTBIR + ETHN + HEIGHT_M + ns(age, df = 2),
-                 random = ~ns(age, df = 2)|ID, 
-                 data = simLong, mess = FALSE)
+                 random = ~ns(age, df = 2) | ID, data = simLong)
 
 ## ---- echo = FALSE--------------------------------------------------------------------------------
 tab <- rbind(norm = c("linear regression", "continuous variables"),
@@ -146,6 +146,17 @@ colnames(tab) <- c('name', 'model', 'variable type')
 
 knitr::kable(tab, row.names = FALSE)
 
+## ---- echo = FALSE--------------------------------------------------------------------------------
+tab <- rbind(lmm = c("linear mixed model", "continuous longitudinal variables"),
+             glmm_logit = c("logistic mixed model", "longitudinal factors with two levels"),
+             clmm = c("cumulative logit mixed model", "longitudinal ordered factors with >2 levels")
+)
+
+tab <- cbind(paste0("`", rownames(tab), "`"), tab)
+colnames(tab) <- c('name', 'model', 'variable type')
+
+knitr::kable(tab, row.names = FALSE)
+
 ## ---- echo = FALSE--------------------------------------------------------------------------------
 tab = rbind(lognorm = c("normal regression of the log-transformed variable",
                         "right-skewed variables >0"),
@@ -160,28 +171,45 @@ colnames(tab) <- c('name', 'model', 'variable type')
 knitr::kable(tab, row.names = FALSE)
 
 
-## ---- cache = TRUE--------------------------------------------------------------------------------
-mod8a <- lm_imp(SBP ~ age + gender + WC + alc + bili + occup + smoke,
-                meth = c(bili = 'gamma', WC = 'lognorm'),
-                data = NHANES, n.iter = 100, mess = FALSE, progress.bar = 'none')
+## ---- echo = FALSE--------------------------------------------------------------------------------
+tab <- rbind(glmm_gamma = c("gamma mixed model (with log-link)",
+                            "longitudinal right-skewed variables >0"),
+             glmm_poisson = c("poisson mixed model (with log-link)",
+                              "longitudinal count variables")
+)
 
-mod8a$meth
+tab <- cbind(paste0("`", rownames(tab), "`"), tab)
+colnames(tab) <- c('name', 'model', 'variable type')
+
+knitr::kable(tab, row.names = FALSE)
+
+## ---- message = FALSE-----------------------------------------------------------------------------
+mod8a <- lm_imp(SBP ~ age + gender + WC + alc + bili + occup + smoke,
+                models = c(bili = 'gamma', WC = 'lognorm'),
+                data = NHANES, n.iter = 100, progress.bar = 'none')
+
+mod8a$models
 
 ## -------------------------------------------------------------------------------------------------
-mod8a_meth <- get_imp_meth(SBP ~ age + gender + WC + alc + bili + occup + smoke,
-                           data = NHANES)
-mod8a_meth
+mod8b_models <- get_models(bmi ~ GESTBIR + ETHN + HEIGHT_M + SMOKE + hc + MARITAL + ns(age, df = 2),
+                           random = ~ns(age, df = 2) | ID, data = simLong)
+mod8b_models
+
+## -------------------------------------------------------------------------------------------------
+mod8c_models <- get_models(bmi ~ GESTBIR + ETHN + HEIGHT_M + SMOKE + hc + MARITAL + ns(age, df = 2),
+                           random = ~ns(age, df = 2) | ID, data = simLong, no_model = "age")
+mod8c_models
 
 ## -------------------------------------------------------------------------------------------------
 # number of missing values in the covariates in mod8a
-colSums(is.na(NHANES[, names(mod8a_meth)]))
+colSums(is.na(NHANES[, names(mod8a$models)]))
 
 # print information on the imputation models (and omit everything but the predictor variables)
 list_impmodels(mod8a, priors = F, regcoef = F, otherpars = F, refcat = F)
 
-## ---- cache = TRUE--------------------------------------------------------------------------------
+## ---- message = FALSE-----------------------------------------------------------------------------
 mod9a <- lm_imp(SBP ~ gender + age + occup, auxvars = c('educ', 'smoke'),
-                data = NHANES, n.iter = 100, progress.bar = 'none', mess = FALSE)
+                data = NHANES, n.iter = 100, progress.bar = 'none')
 
 ## -------------------------------------------------------------------------------------------------
 summary(mod9a)
@@ -189,31 +217,30 @@ summary(mod9a)
 ## -------------------------------------------------------------------------------------------------
 list_impmodels(mod9a, priors = FALSE, regcoef = FALSE, otherpars = FALSE, refcat = FALSE)
 
-## -------------------------------------------------------------------------------------------------
+## ---- message = FALSE-----------------------------------------------------------------------------
 mod9b <- lm_imp(SBP ~ gender + age + occup, data = NHANES,
                 auxvars = c('educ', 'smoke', 'log(WC)'),
-                trunc = list(WC = c(1e-10, 1e10)), n.adapt = 0, mess = FALSE)
+                trunc = list(WC = c(1e-10, 1e10)), n.adapt = 0)
 
 ## -------------------------------------------------------------------------------------------------
 list_impmodels(mod9b, priors = FALSE, regcoef = FALSE, otherpars = FALSE,
                refcat = FALSE)
 
-## -------------------------------------------------------------------------------------------------
+## ---- message = FALSE-----------------------------------------------------------------------------
 mod10a <- lm_imp(SBP ~ gender + age + race + educ + occup + smoke,
-                 refcats = "largest",
-                 data = NHANES, n.adapt = 0, mess = FALSE)
+                 refcats = "largest", data = NHANES, n.adapt = 0)
 
-## -------------------------------------------------------------------------------------------------
+## ---- message = FALSE-----------------------------------------------------------------------------
 mod10b <- lm_imp(SBP ~ gender + age + race + educ + occup + smoke,
                  refcats = list(occup = "not working", race = 3, educ = 'largest'),
-                 data = NHANES, n.adapt = 0, mess = FALSE)
+                 data = NHANES, n.adapt = 0)
 
 ## ---- echo = FALSE--------------------------------------------------------------------------------
 set_refcat <- function(data, formula, covars, auxvars) {
   if (missing(formula) & missing(covars) & missing(auxvars)) {
     covars <- colnames(data)
   } else  if (missing(covars) & !missing(formula)) {
-    covars <- all.vars(formula)[all.vars(formula) != JointAI:::extract_y(formula)]
+    covars <- all.vars(formula)[all.vars(formula) != JointAI:::extract_outcome(formula)]
   }
   if (!missing(auxvars))
     covars <- unique(c(covars, auxvars))
@@ -253,11 +280,10 @@ refs_mod10 <- set_refcat(NHANES, formula = formula(mod10b))
 ## ---- echo = FALSE--------------------------------------------------------------------------------
 refs_mod10 <-  c(gender = 'female', race = 'Non-Hispanic White', educ = 'low', occup = 'not working', smoke = 'never')
 
-## -------------------------------------------------------------------------------------------------
+## ---- message = FALSE-----------------------------------------------------------------------------
 mod10c <- lm_imp(SBP ~ gender + age + race + educ + occup + smoke,
-                 refcats = refs_mod10,
-                 data = NHANES, n.adapt = 0, mess = FALSE)
+                 refcats = refs_mod10, data = NHANES, n.adapt = 0)
 
 ## -------------------------------------------------------------------------------------------------
-default_hyperpars(nranef = 2)
+default_hyperpars()
 
